Skip to contents

the full list of potential substitutions for the geo_value column name: geo_value, geo_values, geo_id, geos, location, jurisdiction, fips, zip, county, hrr, msa, state, province, nation, states, provinces, counties, geo_Value, region, regions, country, countries, state_code, fips_code, zip_code, location_id, location_code, Geo_Value, Geo_Values, Geo_Id, Geos, Location, Jurisdiction, Fips, Zip, County, Hrr, Msa, State, Province, Nation, States, Provinces, Counties, Geo_Value, Region, Regions, Country, Countries, State_Code, Fips_Code, Zip_Code, Location_Id, Location_Code

Usage

geo_column_names()